==> tencentcloud-sdk-java-3.1.87-sources.jar: com/tencentcloudapi/cbs/v20170312/models/DescribeInstancesDiskNumResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cbs.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeInstancesDiskNumResponse extends AbstractModel{

    /**
    * 各个云服务器已挂载和可挂载弹性云盘的数量。
    */
    @SerializedName("AttachDetail")
    @Expose
    private AttachDetail [] AttachDetail;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 各个云服务器已挂载和可挂载弹性云盘的数量。 
     * @return AttachDetail 各个云服务器已挂载和可挂载弹性云盘的数量。
     */
    public AttachDetail [] getAttachDetail() {
        return this.AttachDetail;
    }

    /**
     * Set 各个云服务器已挂载和可挂载弹性云盘的数量。
     * @param AttachDetail 各个云服务器已挂载和可挂载弹性云盘的数量。
     */
    public void setAttachDetail(AttachDetail [] AttachDetail) {
        this.AttachDetail = AttachDetail;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "AttachDetail.", this.AttachDetail);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/cbs/v20170312/models/DescribeInstancesDiskNumResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cbs.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeInstancesDiskNumResponse extends AbstractModel {

    /**
    * 各个云服务器已挂载和可挂载弹性云盘的数量。
    */
    @SerializedName("AttachDetail")
    @Expose
    private AttachDetail [] AttachDetail;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 各个云服务器已挂载和可挂载弹性云盘的数量。 
     * @return AttachDetail 各个云服务器已挂载和可挂载弹性云盘的数量。
     */
    public AttachDetail [] getAttachDetail() {
        return this.AttachDetail;
    }

    /**
     * Set 各个云服务器已挂载和可挂载弹性云盘的数量。
     * @param AttachDetail 各个云服务器已挂载和可挂载弹性云盘的数量。
     */
    public void setAttachDetail(AttachDetail [] AttachDetail) {
        this.AttachDetail = AttachDetail;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeInstancesDiskNumResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeInstancesDiskNumResponse(DescribeInstancesDiskNumResponse source) {
        if (source.AttachDetail != null) {
            this.AttachDetail = new AttachDetail[source.AttachDetail.length];
            for (int i = 0; i < source.AttachDetail.length; i++) {
                this.AttachDetail[i] = new AttachDetail(source.AttachDetail[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "AttachDetail.", this.AttachDetail);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
